        

/**
 * Create a SVG path for an icon that represents a panorama's viewing direction and field-of-view.
 * 
 * @param pan the heading or pan angle of the viewer (clockwise, 0 means north).
 * @param fov the field-of-view angle of the viewer.
 * @return returns an SVG path.
 */
function createSVGPath(pan,fov) {

	// move from pan angle (0° is north) to geometric angle (0° is east).
	pan = pan-90;

	var centerX = 0;
	var centerY = 0;
	var arcSections = 11;
	var i;
	
	var RAD_TO_DEG = 180.0/Math.PI;
	var DEG_TO_RAD = Math.PI/180.0;		
	
	var start = pan-(fov/2);
	var stop = pan+(fov/2);
	var innerArcDistance = 8;
	var outerArcDistance = 40;

	// Draw (move around) the maximum bounds for the symbol, so the symbol can be centered on the photo location.
	var maxDistance = outerArcDistance*1.05;
	var list = [-maxDistance,maxDistance,maxDistance,maxDistance,maxDistance,-maxDistance,-maxDistance,-maxDistance];
	var path = "M"+list[0]+","+list[1]+"M"+list[2]+","+list[3]+"M"+list[4]+","+list[5]+"M"+list[6]+","+list[7];

	// Draw outer arc 
	for (i=0;i<=arcSections;i++)
	{
		var a = start+(i*((stop-start)/arcSections));
		var x = centerX+(Math.cos(DEG_TO_RAD*a)*outerArcDistance);
		var y = centerY+(Math.sin(DEG_TO_RAD*a)*outerArcDistance);
		var type = (i==0) ? "M" : "L";
		path += type+x+","+y;
	}
	
	// Draw inner arc
	for (i=arcSections;i>=0;i--)
	{
		var a = start+(i*((stop-start)/arcSections));
		var x = centerX+(Math.cos(DEG_TO_RAD*a)*innerArcDistance);
		var y = centerY+(Math.sin(DEG_TO_RAD*a)*innerArcDistance);
		path += "L"+x+","+y;
	}
	
	// Close 
	path += "Z";

	// Add Center-line
	var x = centerX+(Math.cos(DEG_TO_RAD*pan)*(outerArcDistance*0.80));
	var y = centerY+(Math.sin(DEG_TO_RAD*pan)*(outerArcDistance*0.80));
	var x2 = centerX+(Math.cos(DEG_TO_RAD*pan)*(outerArcDistance*1.05));
	var y2 = centerY+(Math.sin(DEG_TO_RAD*pan)*(outerArcDistance*1.05));
	path += "M"+x+","+y+"L"+x2+","+y2;

	// Return
	return path;
}